/**
 *
 */
package de.intevation.gnv.artifactdatabase.objects;

import java.util.Collection;
import java.util.Map;

import org.w3c.dom.Node;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 * 
 */
public class Artifact implements ArtifactObject, ArtifactDescription {


    /**
     * The UID of this Class
     */
    private static final long serialVersionUID = 8606869493141810364L;
    
    private String id = null;
    private String hash = null;
    private boolean selected = false;

    private Node currentUI = null;
    private Node currentOut = null;

    private Collection<String> reachableStates;
    private Collection<String> inputParameter;
    private Map<String, OutputMode> outputModes;
    private String currentState = null;

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getCurrentUI()
     */
    public Node getCurrentUI() {
        return currentUI;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setCurrentUI(org.w3c.dom.Node)
     */
    public void setCurrentUI(Node currentUI) {
        this.currentUI = currentUI;
    }

    /**
     * @return the currentOut
     */
    public Node getCurrentOut() {
        return currentOut;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setCurrentOut(org.w3c.dom.Node)
     */
    public void setCurrentOut(Node currentOut) {
        this.currentOut = currentOut;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getReachableStates()
     */
    public Collection<String> getReachableStates() {
        return reachableStates;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setReachableStates(java.util.Collection)
     */
    public void setReachableStates(Collection<String> reachableStates) {
        this.reachableStates = reachableStates;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getCurrentState()
     */
    public String getCurrentState() {
        return currentState;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setCurrentState(java.lang.String)
     */
    public void setCurrentState(String currentState) {
        this.currentState = currentState;
    }

    /**
     * Constructor
     */
    public Artifact(String uuid, String hash) {

        this.id = uuid;
        this.hash = hash;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#getHash()
     */
    public String getHash() {
        return this.hash;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#getDescription()
     */
    public String getDescription() {
        return this.id;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#getId()
     */
    public String getId() {
        return this.id;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#getName()
     */
    public String getName() {
        return this.id;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#isSelected()
     */
    public boolean isSelected() {
        return this.selected;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactObject#setSelected(boolean)
     */
    public void setSelected(boolean selected) {
        this.selected = selected;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getInputParameter()
     */
    public Collection<String> getInputParameter() {
        return this.inputParameter;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setInputParameter(java.util.Collection)
     */
    public void setInputParameter(Collection<String> inputParameter) {
        this.inputParameter = inputParameter;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getOutputModes()
     */
    public Map<String, OutputMode> getOutputModes() {
        return this.outputModes;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#getOutputModesAsCollection()
     */
    public Collection<OutputMode> getOutputModesAsCollection() {
        if (this.outputModes != null) {
            return this.outputModes.values();
        }
        return null;
    }

    /**
     * @see de.intevation.gnv.artifactdatabase.objects.ArtifactDescription#setOutputModes(java.util.Map)
     */
    public void setOutputModes(Map<String, OutputMode> outputModes) {
        this.outputModes = outputModes;
    }
}
